
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class V1::EmailController < ApplicationController
  before_action :authenticate, only: [:create]
  before_action -> { authorize current_user }, only: [:create]

  def create
    email = Email.new(email_params)
    email.role_ids = roles_params[:roles]
    email.user = current_user
    if email.save
      email.emails.each do |address|
        EmailMailer.new_email(email, address).deliver_now
      end
      render status: :ok
    else
      render status: :unprocessable_entity
    end
  end

  protected

  def email_params
    return nil if params[:email].nil?
    params[:email].permit(:all_users, :subject, :body, emails: [])
  end

  def roles_params
    params[:email].permit(roles: [])
  end

  def authenticate
    authenticate_user!
  end

end
